# Generated by roxygen2: do not edit by hand

S3method(get_model_space,bs_surprise)
S3method(get_model_space,bs_surprise_sf)
S3method(get_surprise,bs_surprise)
S3method(get_surprise,bs_surprise_df)
S3method(get_surprise,bs_surprise_sf)
S3method(plot,bs_model_space)
S3method(plot,bs_surprise)
S3method(plot,bs_surprise_sf)
S3method(plot,bs_surprise_temporal)
S3method(print,bs_model)
S3method(print,bs_model_space)
S3method(print,bs_surprise)
S3method(print,bs_surprise_df)
S3method(print,bs_surprise_sf)
S3method(print,bs_surprise_temporal)
S3method(summary,bs_surprise)
S3method(surprise,data.frame)
S3method(surprise,sf)
S3method(surprise,tbl_df)
S3method(update_surprise,bs_surprise)
S3method(update_surprise,bs_surprise_temporal)
export(StatSurprise)
export(StatSurpriseSf)
export(add_model)
export(auto_surprise)
export(bayesian_update)
export(bs_model_baserate)
export(bs_model_baserate_col)
export(bs_model_bootstrap)
export(bs_model_funnel)
export(bs_model_funnel_col)
export(bs_model_gaussian)
export(bs_model_gaussian_mixture)
export(bs_model_sampled)
export(bs_model_uniform)
export(compute_funnel_data)
export(compute_surprise)
export(cumulative_bayesian_update)
export(default_model_space)
export(funnel_pvalue)
export(funnel_zscore)
export(geom_surprise)
export(geom_surprise_density)
export(geom_surprise_histogram)
export(get_model_space)
export(get_surprise)
export(get_surprise_at_time)
export(kl_divergence)
export(log_sum_exp)
export(model_names)
export(model_space)
export(n_models)
export(normalize_minmax)
export(normalize_prob)
export(normalize_rate)
export(normalize_robust)
export(normalize_zscore)
export(remove_model)
export(scale_color_surprise)
export(scale_color_surprise_binned)
export(scale_color_surprise_diverging)
export(scale_color_surprise_thresholds)
export(scale_colour_surprise)
export(scale_colour_surprise_binned)
export(scale_colour_surprise_diverging)
export(scale_colour_surprise_thresholds)
export(scale_fill_surprise)
export(scale_fill_surprise_binned)
export(scale_fill_surprise_diverging)
export(scale_fill_surprise_diverging_binned)
export(scale_fill_surprise_manual)
export(scale_fill_surprise_thresholds)
export(set_prior)
export(st_aggregate_surprise)
export(st_density)
export(st_density_at)
export(st_surprise)
export(stat_surprise)
export(stat_surprise_sf)
export(surprise)
export(surprise_animate)
export(surprise_rolling)
export(surprise_temporal)
export(update_surprise)
importFrom(MASS,bandwidth.nrd)
importFrom(MASS,kde2d)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(cli,cli_warn)
importFrom(ggplot2,waiver)
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(scales,muted)
importFrom(stats,approx)
importFrom(stats,density)
importFrom(stats,dmultinom)
importFrom(stats,dnorm)
importFrom(stats,dpois)
importFrom(stats,sd)
importFrom(stats,weighted.mean)
importFrom(utils,modifyList)
